summaryrefslogtreecommitdiffstats
path: root/src/Authoring/Client/Code/Core/Doc/Doc.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/Authoring/Client/Code/Core/Doc/Doc.cpp')
-rw-r--r--src/Authoring/Client/Code/Core/Doc/Doc.cpp12
1 files changed, 3 insertions, 9 deletions
diff --git a/src/Authoring/Client/Code/Core/Doc/Doc.cpp b/src/Authoring/Client/Code/Core/Doc/Doc.cpp
index b64ceea7..d947e4f1 100644
--- a/src/Authoring/Client/Code/Core/Doc/Doc.cpp
+++ b/src/Authoring/Client/Code/Core/Doc/Doc.cpp
@@ -1970,19 +1970,13 @@ bool CDoc::CanCut()
//==============================================================================
/**
* Handles the duplicate command passed by mainframe.
* Makes a copy of the currently selected item (if there is one) and attaches
* it to the same parent as the original.
*/
void CDoc::HandleDuplicateCommand()
{
- qt3dsdm::Qt3DSDMInstanceHandle theSelectedInstance = GetSelectedInstance();
-
- // If we have a valid object to duplicate
- if (m_StudioSystem->GetClientDataModelBridge()->IsDuplicateable(theSelectedInstance)) {
- using namespace Q3DStudio;
- SCOPED_DOCUMENT_EDITOR(*this, QObject::tr("Duplicate Object"))
- ->DuplicateInstance(GetSelectedInstance());
- }
+ Q3DStudio::SCOPED_DOCUMENT_EDITOR(*this, QObject::tr("Alias Duplicate"))
+ ->CreateAliasDuplicates(GetSelectedValue().GetSelectedInstances(), GetActiveSlide());
}
//=============================================================================
@@ -1970,19 +1970,13 @@ bool CDoc::CanCut()
/**
* Handles the duplicate command passed by mainframe.
- * Makes a copy of the currently selected item (if there is one) and attaches
+ * Makes an alias copy of the currently selected item (if there is one) and attaches
* it to the same parent as the original.
*/